@@ -2,7 +2,8 @@ package JSON::YAJL;
 use strict;
 use warnings;
 use JSON::YAJL::Generator;
-our $VERSION = '0.05';
+use JSON::YAJL::Parser;
+our $VERSION = '0.06';
 
 1;
 
@@ -13,7 +14,7 @@ JSON::YAJL - An interface to the YAJL JSON parsing and generation library
 =head1 SYNOPSIS
 
   use JSON::YAJL;
-  # see JSON::YAJL::Generator
+  # see JSON::YAJL::Generator or JSON::YAJL::Parser
 
 =head1 DESCRIPTION
 
@@ -21,8 +22,9 @@ YAJL is Yet Another JSON Library. YAJL is a small event-driven (SAX-style) JSON
 parser written in ANSI C, and a small validating JSON generator, by Lloyd
 Hilaiel This module is a Perl interface to that library.
 
-At the moment this only wraps the generation library, see
-L<JSON::YAJL::Generator>. Patches for parsing welcome.
+At the moment this wraps the generation library, see
+L<JSON::YAJL::Generator> and the parsing library, see
+L<JSON::YAJL::Parser>.
 
 This is a very early release to see how cross-platform the underlying code is.
 The API may change in future.
@@ -37,4 +39,4 @@ This module is free software; you can redistribute it or modify it under the sam
 
 =head1 SEE ALSO
 
-L<JSON::YAJL::Generator>
+L<JSON::YAJL::Generator>, L<JSON::YAJL::Parser>
